#
# spec file for package libpinyin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 15

Name:           libpinyin
Version:        2.8.1
Release:        1.9
Summary:        Intelligent Pinyin IME
License:        GPL-3.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/libpinyin/libpinyin
Source:         https://github.com/libpinyin/libpinyin/releases/download/%{version}/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(kyotocabinet)

%description
libpinyin is an intelligent (and universal) sentence-based Pinyin IME
backend supporting many language models and frontends.

%package -n %{name}%{sover}
Summary:        Intelligent Pinyin IME
Group:          System/Libraries
Requires:       %{name}-data

%description -n %{name}%{sover}
libpinyin is a staging joint effort of many Chinese Pinyin IME development
teams. It is an intelligent (and universal) sentence-based Pinyin IME backend
supporting many language models and frontends.

This package provides runtime library for libpinyin.

%package -n libzhuyin%{sover}
Summary:        Intelligent Pinyin IME
Group:          System/Libraries
Requires:       %{name}-data

%description -n libzhuyin%{sover}
libpinyin is a staging joint effort of many Chinese Pinyin IME development
teams. It is an intelligent (and universal) sentence-based Pinyin IME backend
supporting many language models and frontends.

This package provides runtime library for libpinyin.

%package data
Summary:        Data files for the libpinyin IME
Group:          System/I18n/Chinese

%description data
libpinyin is an intelligent (and universal) sentence-based Pinyin IME
backend supporting many language models and frontends.

This package provides language model table data for libpinyin.

%package devel
Summary:        Development files for the libpinyin IME
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}
Requires:       %{name}-tools = %{version}
Requires:       libzhuyin%{sover} = %{version}
Provides:       libzhuyin-devel = %{version}

%description devel
libpinyin is an intelligent (and universal) sentence-based Pinyin IME
backend supporting many language models and frontends.

This subpackage contains the development files.

%package tools
Summary:        Tools for libpinyin
Group:          System/I18n/Chinese

%description tools
libpinyin is an intelligent (and universal) sentence-based Pinyin IME
backend supporting many language models and frontends.

This package provides the tools used to make data files.

%prep
%setup -q

%build
# autoreconf -ifv
%configure \
    --disable-static \
    --with-dbm=KyotoCabinet \
    --disable-silent-rules \
    --enable-libzhuyin
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}/%{_prefix}

%check
make %{?_smp_mflags} check

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig
%post -n libzhuyin%{sover} -p /sbin/ldconfig
%postun -n libzhuyin%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%defattr(-,root,root)
%{_libdir}/%{name}.so.*

%files -n libzhuyin%{sover}
%defattr(-,root,root)
%{_libdir}/libzhuyin.so.*

%files data
%defattr(-,root,root)
%doc ChangeLog AUTHORS README NEWS
%license COPYING
%{_libdir}/%{name}

%files tools
%defattr(-,root,root)
%doc ChangeLog AUTHORS README NEWS
%license COPYING
%{_bindir}/gen_binary_files
%{_bindir}/gen_unigram
%{_bindir}/import_interpolation

%files devel
%defattr(-,root,root)
%doc ChangeLog AUTHORS README NEWS
%license COPYING
%{_includedir}/%{name}-*/
%{_libdir}/%{name}.so
%{_libdir}/libzhuyin.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/libzhuyin.pc
%{_mandir}/man1/libpinyin.1%{ext_man}

%changelog
* Tue Feb 21 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.8.1
  * Fix bugs
  * Improve suggestion candidates
  * Support longer candidates
* Wed Apr 13 2022 Dingzhong Chen <wsxy162@gmail.com>
- Update version to 2.6.2
  * Fix libzhuyin linkage when using LLVM linker
  * Switch from GrassDB to ProtoTreeDB
* Thu Sep 16 2021 Dingzhong Chen <wsxy162@gmail.com>
- Update version to 2.6.1
  * bug fixes
* Sat Jan  9 2021 Dingzhong Chen <wsxy162@gmail.com>
- Update version to 2.6.0
  * bug fixes
* Fri Oct 23 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.4.92
  * update pinyin data
  * bug fixes
* Tue Sep  8 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.4.91
  * improve full pinyin auto correction
  * bug fixes
- Drop libpinyin-1.7.0-no-AX_CXX_COMPILE_STDCXX_11.patch, no longer
  support Leap 42
* Sat Sep  5 2020 Marguerite Su <i@marguerite.su>
- add libzhuyin%%{sover} to libpinyin-devel
* Mon Mar 25 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 2.3.0
  * Update pinyin data
- Drop libpinyin-avoid_download_at_buildtime.patch, merged by upstream.
* Thu Feb 14 2019 hillwood@opensuse.org
- Update version to 2.2.2
  * minor fixes
* Thu Oct 11 2018 hillwood@opensuse.org
- Update version to 2.2.1
  * Fix predicted candidates
* Mon May 14 2018 hillwood@opensuse.org
- Update version to 2.2.0
  * Bug fixes
- Drop libpinyin-fix_double_pinyin.patch. Fixed with other way by upstream.
* Mon Mar  5 2018 hillwood@opensuse.org
- Update version to 2.1.91
  * Fix zhuyin parsers
  * Use model15.
* Sun Oct  8 2017 jengelh@inai.de
- Move documentation to libpinyin-devel. Manpages do not belong
  into libpinyin13 (SLPP guideline).
- Avoid running fdupes across partition boundaries.
* Tue Aug 29 2017 hillwood@opensuse.org
- Update to 2.1.0
  * support sort option in pinyin_guess_candidates function
* Tue Aug 22 2017 hillwood@opensuse.org
- Enable zhuyin support.
* Tue Aug 22 2017 hillwood@opensuse.org
- Update to 2.0.92
  * reduce memory consumption after imported user dictionary;
  * merge libzhuyin code;
  * fixes autoconf;
  * multiple sentence candidates;
* Thu Jun 22 2017 tchvatal@suse.com
- Switch to kyotocabinet from libdb so it could be removed
- Enable tests
- Remove needless buildrequires
* Thu Feb  2 2017 jengelh@inai.de
- Trim descriptions and ensure fdupes does not run across
  potential partitions.
- Rename %%soname to %%sover to better reflect its use.
* Tue Jan 31 2017 i@marguerite.su
- add libpinyin-1.7.0-no-AX_CXX_COMPILE_STDCXX_11.patch
  * AX_CXX_COMPILE_STDCXX([11]) breaks build on Leap 42.1 while
    no actual use
* Tue Jan 31 2017 i@marguerite.su
- update version 1.7.0
  * fixes build on FreeBSD;
  * update cmake files;
- changes in version 1.6.91
  * change license to GPLv3+;
  * import open-gram dictionary and remove pinyin tones;
  * add some checks when load data from file;
* Thu Sep  8 2016 hillwood@opensuse.org
- Update to 1.6.0
  * fixes https://github.com/libpinyin/ibus-libpinyin/issues/56
  * fixes pinyin_remember_user_input function
  * fixes pinyin_get_character_offset function
  * fixes compute_pronunciation_possibility function
  * fixes pinyin_get_character_offset function
* Wed Aug 10 2016 hillwood@opensuse.org
- Update to 1.5.92
  * use model12.text.tar.gz
  * fixes pinyin_get_character_offset function
  * fixes _get_char_offset_recur function
  * fixes _pre_compute_tokens function
  * fixes fill_matrix function
  * fixes pinyin_get_right_pinyin_offset function
  * fixes fill_matrix function
  * clean up FullPinyinParser2
- Update libpinyin-avoid_download_at_buildtime.patch
- Update baselibs.conf
- Add libpinyin-fix_double_pinyin.patch
  * fix mapper for double pinyin
* Thu Dec 24 2015 i@marguerite.su
- Update to version 1.3.0+git20151204.7b790c9:
  * support force tone in pinyin parsers
  * support fallback tables in double pinyin
  * many bugfixes and refactors
- drop patch: libpinyin-1.2.0-avoid_download_at_buildtime.patch
- add patch: libpinyin-avoid_download_at_buildtime.patch
* Tue Aug 25 2015 i@marguerite.su
- Update to version 1.2.0+git20150731.958c597:
  * fixes Kyoto Cabinet bug
  * Resolve NULL used in arithmetic
  * Resolve ambiguos usage of log(3)
  * bump version 1.2.0
- add patch: libpinyin-1.2.0-avoid_download_at_buildtime.patch
- remove patch: libpinyin-1.0.99.20150212-avoid_download_at_buildtime.patch
* Wed Apr  8 2015 hillwood@linuxfans.org
- Update to 1.1.0
  * support to export user phrases.
* Sun Feb 15 2015 hillwood@linuxfans.org
- Update to 1.0.99.20150212
  * fixes pinyin_get_pinyin_key_rest_offset method
  * fixes pinyin_iterator_get_next_phrase method
- Update patch file:
  remove old: libpinyin-1.0.0-avoid_download_at_buildtime.patch
  add new: libpinyin-1.0.99.20150212-avoid_download_at_buildtime.patch
* Sat Jul 26 2014 i@marguerite.su
- add libpinyin-tools to libpinyin-devel requirement
- fix factory builds for fcitx-libpinyin
* Wed Jul 16 2014 i@marguerite.su
- use update-alternatives to resolve conflicts with libzhuyin
* Fri Feb 28 2014 hillwood@linuxfans.org
- update to 1.0.0
  * bug fixes
  * added some pinyins, such as "陆 liu4", "单 shan4".
- update patch file.
* Wed Jun 26 2013 i@marguerite.su
- update version 0.9.93
  * see commit log for collective updates.
  * https://github.com/libpinyin/libpinyin/commits/master
- add patch: libpinyin-0.9.0-avoid_download_at_buildtime.patch
* Wed Dec 19 2012 hillwood@linuxfans.org
- update 0.8.0.
  bug fixes
* Thu Oct 11 2012 i@marguerite.su
- update 0.7.91
  * a code refator release
* Sun Sep 16 2012 i@marguerite.su
- use upstream standard source.
* Fri Sep 14 2012 i@marguerite.su
- fix fedora builds.
* Mon Sep 10 2012 hillwood@linuxfans.org
- update to 0.7.1
  more changelog please visit http://goo.gl/9bsJj ,only Chinese.
* Mon Aug  6 2012 aj@suse.de
- Remove obsoletes/provides, they are not correct.
* Tue Jul 31 2012 i@marguerite.su
- fix Obsoltes/Provides as AJ suggested.
* Sun Jul 29 2012 hillwood@linuxfans.org
- update to 0.7.0
  * fixes cmake
* Mon Jul 16 2012 hillwood@linuxfans.org
- update to 0.6.92
  * update test_pinyin
  * update utils
* Fri Jun 22 2012 hillwood@linuxfans.org
- update to 0.6.91
- add cmake scripts
- fixes jv,ju in ABC and more
* Sat Jun  2 2012 i@marguerite.su
- fix sles builds.
* Sun Jan 29 2012 i@marguerite.su
- fix Factory libtool build error.
* Sat Jan 28 2012 i@marguerite.su
- Initial package from libpinyin git, version 0.5
